==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/plugins/General/lyrics/translations/lyrics_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="33"/>
        <source>View Lyrics</source>
        <translation>显示歌词</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="34"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>歌词插件</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>关于歌词插件</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Qmmp 歌词插件</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>此插件使用的歌词来源于 LyricWiki</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>歌词插件</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="45"/>
        <source>Artist:</source>
        <translation>艺术家：</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="55"/>
        <source>Title:</source>
        <translation>标题：</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="65"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="36"/>
        <source>No connection</source>
        <translation>无连接</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="76"/>
        <location filename="../lyricswindow.cpp" line="207"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="79"/>
        <location filename="../lyricswindow.cpp" line="103"/>
        <location filename="../lyricswindow.cpp" line="109"/>
        <location filename="../lyricswindow.cpp" line="117"/>
        <location filename="../lyricswindow.cpp" line="125"/>
        <location filename="../lyricswindow.cpp" line="136"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="130"/>
        <location filename="../lyricswindow.cpp" line="163"/>
        <source>Not found</source>
        <translation>没有发现</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="150"/>
        <location filename="../lyricswindow.cpp" line="176"/>
        <source>Receiving</source>
        <translation>接受</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="177"/>
        <source>Lyrics: %1 - %2</source>
        <translation>歌词：%1 - %2</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/General/lyrics/translations/lyrics_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="33"/>
        <source>View Lyrics</source>
        <translation>显示歌词</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="34"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="30"/>
        <source>Lyrics Plugin</source>
        <translation>歌词插件</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>关于歌词插件</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Qmmp 歌词插件</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>此插件使用的歌词来源于 LyricWiki</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="54"/>
        <source>Based on Ultimate Lyrics script by Vladimir Brkic &lt;vladimir_brkic@yahoo.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>歌词插件</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Provider:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="122"/>
        <source>Album:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="139"/>
        <source>Track:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="146"/>
        <source>Artist:</source>
        <translation>艺术家：</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="161"/>
        <source>Year:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="115"/>
        <source>Title:</source>
        <translation>标题：</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="113"/>
        <source>&lt;h2&gt;%1 - %2&lt;/h2&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="124"/>
        <source>Not found</source>
        <translation>没有发现</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="134"/>
        <source>Error: %1 - %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="147"/>
        <source>Receiving</source>
        <translation>接受</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="202"/>
        <source>cache</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Lyrics Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Lyrics providers:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UltimateLyricsParser</name>
    <message>
        <location filename="../ultimatelyricsparser.cpp" line="119"/>
        <source>%1 (line: %2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
